@@ -10,7 +10,7 @@ use Data::Dumper;
 use Sys::Hostname;
 use Plack::Util;
 
-our $VERSION = '1.03_1';
+our $VERSION = '1.03_2';
 
 # Basic attributes
 attr -host => hostname;
@@ -60,6 +60,35 @@ sub new {
     return $self;
 }
 
+my $last_anon = 0;
+sub new_anon {
+    my $class = shift;
+
+    # make sure we don't eval something dodgy
+    die "invalid class $class"
+        unless !ref $class && $class->isa(__PACKAGE__);
+
+    my $anon_class = "Kelp::Anonymous::$class" . ++$last_anon;
+    my $err = do {
+        local $@;
+        my $eval_status = eval qq[
+            {
+                package $anon_class;
+                use parent -norequire, '$class';
+            }
+            1;
+        ];
+        $@ || !$eval_status;
+    };
+
+    if ($err) {
+        die "Couldn't create anonymous Kelp instance: " .
+            (length $err > 1 ? $err : 'unknown error');
+    }
+
+    return $anon_class->new(@_);
+}
+
 sub _load_config {
     my $self = shift;
     $self->load_module( $self->config_module, extra => $self->__config );
@@ -429,6 +458,25 @@ contain a reference to the current L<Kelp::Response> instance.
 
 =head1 METHODS
 
+=head2 new
+
+    my $the_only_kelp = KelpApp->new;
+
+A standard constructor. B<Cannot> be called multiple times: see L</new_anon>.
+
+=head2 new_anon
+
+    my $kelp1 = KelpApp->new_anon(config => 'conf1');
+    my $kelp2 = KelpApp->new_anon(config => 'conf2');
+
+A constructor that can be called repeatedly. Cannot be mixed with L</new>.
+
+It works by creating a new anonymous class extending the class of your
+application and running I<new> on it. C<ref $kelp> will return I<something
+else> than the name of your Kelp class, but C<< $kelp->isa('KelpApp') >> will
+be true. This will likely be useful during testing or when running multiple
+instances of the same application with different configurations.
+
 =head2 build
 
 On its own, the C<build> method doesn't do anything. It is called by the
